@@ -247,7 +247,6 @@ TSRANGE 1925 1 1941 1
 EQ> EXP(cn) = a1 + a2*p + a3*LAG(p,1) + a4*(w1+w2)
 COEFF> a1 a2 a3 a4
 ERROR> AUTO(2)
-STORE> coe(1)
 
 COMMENT> Log Investment
 BEHAVIORAL> i
@@ -255,7 +254,6 @@ TSRANGE 1925 1 1941 1
 EQ> LOG(i) = b1 + b2*p + b3*LAG(p,1) + b4*LAG(k,1)
 COEFF> b1 b2 b3 b4
 RESTRICT> b2 + b3 = 1
-STORE> coe(15)
 
 COMMENT> Demand for Labor
 BEHAVIORAL> w1
@@ -263,7 +261,6 @@ TSRANGE 1925 1 1941 1
 EQ> w1 = c1 + c2*(TSDELTA(y)+t-w2) + c3*LAG(TSDELTA(y)+t-w2,1)+c4*time
 COEFF> c1 c2 c3 c4
 PDL> c3 1 3
-STORE> coe(29)
 
 COMMENT> Delta Gross National Product
 IDENTITY> y
@@ -276,10 +273,10 @@ EQ> p = TSDELTA(y) - (w1+w2)
 COMMENT> Capital Stock with switches
 IDENTITY> k
 EQ> k = LAG(k,1) + LOG(i)
-IF> LOG(i).GT.0
+IF> LOG(i) > 0
 IDENTITY> k
 EQ> k = LAG(k,1)
-IF> LOG(i).LE.0
+IF> LOG(i) <= 0
 
 END"
 
@@ -314,19 +311,19 @@ lhsKleinModel <- SIMULATE(lhsKleinModel, TSRANGE = c(1925,1,1930,1))
 
 
 ###################################################
-### code chunk number 27: bimets.Rnw:637-638
+### code chunk number 27: bimets.Rnw:634-635
 ###################################################
 kleinModel <- ESTIMATE(kleinModel, quietly=TRUE)
 
 
 ###################################################
-### code chunk number 28: bimets.Rnw:643-644
+### code chunk number 28: bimets.Rnw:640-641
 ###################################################
 kleinModel <- ESTIMATE(kleinModel, eqList=c('cn'))
 
 
 ###################################################
-### code chunk number 29: bimets.Rnw:649-659
+### code chunk number 29: bimets.Rnw:646-656
 ###################################################
 #print estimated coefficients
 kleinModel$behaviorals$cn$coefficients
@@ -341,7 +338,7 @@ kleinModel$behaviorals$cn$statistics$LogLikelihood
 
 
 ###################################################
-### code chunk number 30: bimets.Rnw:667-712
+### code chunk number 30: bimets.Rnw:664-709
 ###################################################
 #define model
 advancedKlein1.txt <- 
@@ -391,7 +388,7 @@ END"
 
 
 ###################################################
-### code chunk number 31: bimets.Rnw:714-717
+### code chunk number 31: bimets.Rnw:711-714
 ###################################################
 #load model and data
 advancedKleinModel <- LOAD_MODEL(modelText=advancedKlein1.txt)
@@ -399,14 +396,14 @@ advancedKleinModel <- LOAD_MODEL_DATA(advancedKleinModel,kleinModelData)
 
 
 ###################################################
-### code chunk number 32: bimets.Rnw:719-721
+### code chunk number 32: bimets.Rnw:716-718
 ###################################################
 #estimate model
 advancedKleinModel <- ESTIMATE(advancedKleinModel)
 
 
 ###################################################
-### code chunk number 33: bimets.Rnw:756-763
+### code chunk number 33: bimets.Rnw:753-760
 ###################################################
 #chow test for the consumption equation
 #base TSRANGE set to 1921/1935
@@ -418,7 +415,7 @@ kleinModelChow <- ESTIMATE(kleinModel
 
 
 ###################################################
-### code chunk number 34: bimets.Rnw:834-854
+### code chunk number 34: bimets.Rnw:831-851
 ###################################################
 #FORECAST GNP in 1942 and 1943 
 #we need to extend exogenous variables in 1942 and 1943
@@ -473,7 +470,7 @@ kleinModel <- SIMULATE(kleinModel
 
 
 ###################################################
-### code chunk number 36: bimets.Rnw:946-953
+### code chunk number 36: bimets.Rnw:943-950
 ###################################################
 kleinModel <- MULTMATRIX(kleinModel,
                         TSRANGE=c(1941,1,1941,1),
@@ -485,7 +482,7 @@ kleinModel$MultiplierMatrix
 
 
 ###################################################
-### code chunk number 37: bimets.Rnw:959-968
+### code chunk number 37: bimets.Rnw:956-965
 ###################################################
 #multi-period interim multipliers
 kleinModel <- MULTMATRIX(kleinModel,
@@ -499,7 +496,7 @@ kleinModel$MultiplierMatrix
 
 
 ###################################################
-### code chunk number 38: bimets.Rnw:991-997
+### code chunk number 38: bimets.Rnw:988-994
 ###################################################
 #we want an arbitrary value on Consumption of 66 in 1940 and 78 in 1941
 #we want an arbitrary value on GNP of 77 in 1940 and 98 in 1941
@@ -521,7 +518,7 @@ kleinModel <- RENORM(kleinModel
 
 
 ###################################################
-### code chunk number 40: bimets.Rnw:1013-1020
+### code chunk number 40: bimets.Rnw:1010-1017
 ###################################################
 with(kleinModel,TABIT(modelData$w2,
                       renorm$INSTRUMENT$w2,
@@ -533,21 +530,21 @@ with(kleinModel,TABIT(modelData$w2,
 
 
 ###################################################
-### code chunk number 41: bimets.Rnw:1027-1029
+### code chunk number 41: bimets.Rnw:1024-1026
 ###################################################
 #create a new model
 kleinRenorm <- kleinModel
 
 
 ###################################################
-### code chunk number 42: bimets.Rnw:1031-1033
+### code chunk number 42: bimets.Rnw:1028-1030
 ###################################################
 #get instruments to be used
 newInstruments <- kleinModel$renorm$INSTRUMENT
 
 
 ###################################################
-### code chunk number 43: bimets.Rnw:1035-1046
+### code chunk number 43: bimets.Rnw:1032-1043
 ###################################################
 #change exogenous by using new instruments data
 kleinRenorm$modelData <- within(kleinRenorm$modelData,
@@ -563,7 +560,7 @@ kleinRenorm$modelData <- within(kleinRenorm$modelData,
 
 
 ###################################################
-### code chunk number 44: bimets.Rnw:1048-1054
+### code chunk number 44: bimets.Rnw:1045-1051
 ###################################################
 #simulate the new model
 kleinRenorm <- SIMULATE(kleinRenorm
@@ -574,7 +571,7 @@ kleinRenorm <- SIMULATE(kleinRenorm
 
 
 ###################################################
-### code chunk number 45: bimets.Rnw:1056-1060
+### code chunk number 45: bimets.Rnw:1053-1057
 ###################################################
 #verify targets are achieved
 with(kleinRenorm$simulation,
